# SearchSource: EBSCOHost

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work)
- supported (details): run_search (including updates), load,  prep (including get_masterdata)

Export is available after adding citations to a folder ([1](https://connect.ebsco.com/s/article/How-to-Use-the-Export-Manager?language=en_US)).

[EBSCOHost](https://search.ebscohost.com/)
[EBSCOHost APIs](https://developer.ebsco.com/getting-started/available-apis)

## Add the search source

Download search results and store in `data/search/` directory. API-access not yet available.

## Links
